@@ -6,7 +6,6 @@ from .base import (
     instance_option,
     map_to_click_exceptions,
 )
-from ..consts import collection_drafts
 
 
 class IntColonInt(click.ParamType):
@@ -51,6 +50,9 @@ class IntColonInt(click.ParamType):
     type=IntColonInt(),
     help="Number of files to upload in parallel and, optionally, number of upload threads per file",
 )
+@click.option(
+    "--sync", is_flag=True, help="Delete assets on the server that do not exist locally"
+)
 @click.option(
     "--validation",
     help="Data must pass validation before the upload.  Use of this option is highly discouraged.",
@@ -64,19 +66,6 @@ class IntColonInt(click.ParamType):
 #
 # TODO: should always go to dandi for now
 @instance_option()
-# TODO: should always go into 'drafts' (consts.collection_drafts)
-@devel_option(
-    "-c", "--girder-collection", help="For development: Girder collection to upload to"
-)
-# TODO: figure out folder for the dandiset
-@devel_option("--girder-top-folder", help="For development: Girder top folder")
-#
-@devel_option(
-    "--fake-data",
-    help="For development: fake file content (filename will be stored instead of actual load)",
-    default=False,
-    is_flag=True,
-)
 @devel_option(
     "--allow-any-path",
     help="For development: allow DANDI 'unsupported' file types/paths",
@@ -94,14 +83,12 @@ class IntColonInt(click.ParamType):
 def upload(
     paths,
     jobs,
+    sync,
     existing="refresh",
     validation="require",
     dandiset_path=None,
     # Development options should come as kwargs
-    girder_collection=collection_drafts,
-    girder_top_folder=None,
     dandi_instance="dandi",
-    fake_data=False,  # TODO: not implemented, prune?
     allow_any_path=False,
     upload_dandiset_metadata=False,
     devel_debug=False,
@@ -132,13 +119,11 @@ def upload(
         existing=existing,
         validation=validation,
         dandiset_path=dandiset_path,
-        girder_collection=girder_collection,
-        girder_top_folder=girder_top_folder,
         dandi_instance=dandi_instance,
-        fake_data=fake_data,
         allow_any_path=allow_any_path,
         upload_dandiset_metadata=upload_dandiset_metadata,
         devel_debug=devel_debug,
         jobs=jobs,
         jobs_per_file=jobs_per_file,
+        sync=sync,
     )
