@@ -244,9 +244,16 @@ def validate(path, devel_debug=False):
     try:
         with pynwb.NWBHDF5IO(path, "r", load_namespaces=True) as reader:
             errors = pynwb.validate(reader)
+        lgr.warning(
+            "pynwb validation errors for %s: %s",
+            path,
+            errors,
+            extra={"validating": True},
+        )
     except Exception as exc:
         if devel_debug:
             raise
+        lgr.warning("Failed to validate %s: %s", path, exc, extra={"validating": True})
         errors = [f"Failed to validate {path}: {exc}"]
 
     # To overcome
